<?php
/**
 * Copyright since 2007 PrestaShop SA and Contributors
 * PrestaShop is an International Registered Trademark & Property of PrestaShop SA
 *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the Academic Free License 3.0 (AFL-3.0)
 * that is bundled with this package in the file LICENSE.md.
 * It is also available through the world-wide-web at this URL:
 * https://opensource.org/licenses/AFL-3.0
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to license@prestashop.com so we can send you a copy immediately.
 *
 * DISCLAIMER
 *
 * Do not edit or add to this file if you wish to upgrade PrestaShop to newer
 * versions in the future. If you wish to customize PrestaShop for your
 * needs please refer to https://devdocs.prestashop.com/ for more information.
 *
 * @author    PrestaShop SA and Contributors <contact@prestashop.com>
 * @copyright Since 2007 PrestaShop SA and Contributors
 * @license   https://opensource.org/licenses/AFL-3.0 Academic Free License 3.0 (AFL-3.0)
 */

if (!defined('_PS_VERSION_')) {
    exit;
}

use PrestaShop\PrestaShop\Core\Module\WidgetInterface;

class Cp_Themeoptions extends Module implements WidgetInterface
{
    /**
     * @var string Name of the module running on PS 1.7.x. Used for data migration.
     */
    protected $html = '';
    protected $currentIndex;
    protected $image_folder = 'views/img/';
    private $templateFile;    

    public function __construct()
    {
        $this->name = 'cp_themeoptions';
        $this->tab = 'front_office_features';
        $this->version = '1.0.0';
        $this->author = 'CoderPlace';
        $this->need_instance = 0;

        $this->bootstrap = true;
        parent::__construct();

        $this->displayName = $this->trans('CP - Theme Options', array(), 'Modules.Themeoptions.Admin');
        $this->description = $this->trans('Theme options help you to change color, fonts and other theme related settings in a visual and friendly way.', array(), 'Modules.Themeoptions.Admin');

        $this->ps_versions_compliancy = array('min' => '1.7.0.0', 'max' => _PS_VERSION_);

        $this->templateFile = 'module:cp_themeoptions/views/templates/hook/cp_themeoptions.tpl';
        $this->currentIndex = AdminController::$currentIndex.'&configure='.$this->name;
    }   

    public function install()
    {
        
        return (parent::install() &&
            $this->registerHook('displayFooter') &&
            $this->registerHook('displayFooterAfter') &&
            $this->registerHook('displayHeader')  &&            
            $this->createConfiguration());
    }

    public function uninstall()
    {
        $this->deleteConfiguration();

        return parent::uninstall();
    }

    //DONGND:: create configs
	public function createConfiguration()
    {

        //DONGND:: create config option for theme settings
        Configuration::updateValue('CPCONTROL_PANEL', 1);        
        Configuration::updateValue('CPPRIMARY_COLOR', '#fad505');
        Configuration::updateValue('CPSECONDARY_COLOR', '#303840');
        Configuration::updateValue('CPPRICE_COLOR', '#a90000');
        Configuration::updateValue('CPLINKHOVER_COLOR', '#0961b3');   
        Configuration::updateValue('CPBODY_FONT', 'Heebo');
        Configuration::updateValue('CPBODY_FONT_SIZE', '15px');        
        Configuration::updateValue('CPTITLE_FONT', 'Heebo');        
        Configuration::updateValue('CPTITLE_FONT_SIZE', '18px');        
        Configuration::updateValue('CPBOX_LAYOUT', 0);
        Configuration::updateValue('CPBOX_BODYBKG_COLOR', '#F0F0F0');
        Configuration::updateValue('CPBOX_BGIMG', 'boxed-bg.png');
        Configuration::updateValue('CPBOX_BGIMG_STYLE', 'repeat');
        Configuration::updateValue('CPSTICKY_HEADER', 0);
        Configuration::updateValue('CPBORDER_RADIUS', 1);
        Configuration::updateValue('CPDISPLAY_PRODUCT_VARIANTS', 1);
        Configuration::updateValue('CPCUSTOM_CSS', '');
        return true;
    }

    //DONGND:: delete configs
	public function deleteConfiguration()
    {	

        //DONGND:: delete config option for theme settings
        Configuration::deleteByName('CPCONTROL_PANEL');        
        Configuration::deleteByName('CPPRIMARY_COLOR');
        Configuration::deleteByName('CPSECONDARY_COLOR');
        Configuration::deleteByName('CPPRICE_COLOR');
        Configuration::deleteByName('CPLINKHOVER_COLOR');      
        Configuration::deleteByName('CPBODY_FONT');
        Configuration::deleteByName('CPBODY_FONT_SIZE');
        Configuration::deleteByName('CPTITLE_FONT');
        Configuration::deleteByName('CPTITLE_FONT_SIZE');
        Configuration::deleteByName('CPBOX_LAYOUT');
        Configuration::deleteByName('CPBOX_BODYBKG_COLOR');
        Configuration::deleteByName('CPBOX_BGIMG');
        Configuration::deleteByName('CPBOX_BGIMG_STYLE');
        Configuration::deleteByName('CPSTICKY_HEADER');
        Configuration::deleteByName('CPBORDER_RADIUS'); 
        Configuration::deleteByName('CPDISPLAY_PRODUCT_VARIANTS');         
        Configuration::deleteByName('CPCUSTOM_CSS');

        return true;
        
    }

    //DONGND:: Set Values for input
    protected function getGroupFieldsValues()
    {	
        return array(
            'CPCONTROL_PANEL' => Configuration::get('CPCONTROL_PANEL'),            
            'CPPRIMARY_COLOR' => Configuration::get('CPPRIMARY_COLOR'),
            'CPSECONDARY_COLOR' => Configuration::get('CPSECONDARY_COLOR'),
            'CPPRICE_COLOR' => Configuration::get('CPPRICE_COLOR'),
            'CPLINKHOVER_COLOR' => Configuration::get('CPLINKHOVER_COLOR'),            
            'CPBODY_FONT' => Configuration::get('CPBODY_FONT'),
            'CPTITLE_FONT' => Configuration::get('CPTITLE_FONT'),
            'CPBODY_FONT_SIZE' => Configuration::get('CPBODY_FONT_SIZE'),            
            'CPTITLE_FONT_SIZE' => Configuration::get('CPTITLE_FONT_SIZE'),
            'CPBOX_LAYOUT' => Configuration::get('CPBOX_LAYOUT'),
            'CPBOX_BODYBKG_COLOR' => Configuration::get('CPBOX_BODYBKG_COLOR'),
            'CPBOX_BGIMG' => Configuration::get('CPBOX_BGIMG'),
            'CPBOX_BGIMG_STYLE' => Configuration::get('CPBOX_BGIMG_STYLE'),
            'CPSTICKY_HEADER' => Configuration::get('CPSTICKY_HEADER'),
            'CPBORDER_RADIUS' => Configuration::get('CPBORDER_RADIUS'),
            'CPDISPLAY_PRODUCT_VARIANTS' => Configuration::get('CPDISPLAY_PRODUCT_VARIANTS'),
            'CPCUSTOM_CSS' => Configuration::get('CPCUSTOM_CSS'),
        );
    }
    
    
    public function hookDisplayHeader()
    {        
        $this->context->controller->addJS($this->_path.'views/js/frontdesign.js');
        $this->context->controller->addCSS($this->_path.'views/css/frontdesign.css');
        $this->context->controller->addJqueryPlugin('fancybox');

        if (Configuration::get('CPCONTROL_PANEL'))
		{
            $this->context->controller->addJS($this->_path.'views/js/jquery.minicolors.min.js');
            $this->context->controller->addJS($this->_path.'views/js/controllpanel.js');
                    
            $this->context->controller->addCSS($this->_path.'views/css/jquery.minicolors.css');
            $this->context->controller->addCSS($this->_path.'views/css/controllpanel.css');
        }

        Media::addJsDef(
            array(
                'CPBOX_LAYOUT' => Configuration::get('CPBOX_LAYOUT'),
                'CPSTICKY_HEADER' => Configuration::get('CPSTICKY_HEADER'),
                'CPBORDER_RADIUS' => Configuration::get('CPBORDER_RADIUS'),
                'CPDISPLAY_PRODUCT_VARIANTS' => Configuration::get('CPDISPLAY_PRODUCT_VARIANTS'),
            )
        );
        
        $this->context->smarty->assign(array(
            'bodyFont' => Configuration::get('CPBODY_FONT'),
            'titleFont' => Configuration::get('CPTITLE_FONT'),
            'customCSSCode' => Configuration::get('CPCUSTOM_CSS'),
        ));
        
        return $this->display(__FILE__, 'header.tpl');

    }

    public function hookDisplayFooterAfter()
    {
        $fontArray  =  array(
            array('id' => 'Inter', 'name' => 'Inter', 'link' => 'Inter:wght@100;200;300;400;500;600;700;800;900&display=swap'),
            array('id' => 'Roboto+Slab', 'name' => 'Roboto Slab', 'link' => 'Roboto+Slab:wght@100;200;300;400;500;600;700;800;900&display=swap'),
            array('id' => 'Lora', 'name' => 'Lora', 'link' => 'Lora:wght@400;500;600;700&display=swap'),
            array('id' => 'Open+Sans', 'name' => 'Open Sans', 'link' => 'Open+Sans:wght@300;400;500;600;700;800&display=swap'),
            array('id' => 'Montserrat', 'name' => 'Montserrat', 'link' => 'Montserrat:wght@100;200;300;400;500;600;700;800;900&display=swap'),
            array('id' => 'Merriweather', 'name' => 'Merriweather', 'link' => 'Merriweather:wght@300;400;700;900&display=swap'),                        
            array('id' => 'Mulish', 'name' => 'Mulish', 'link' => 'Mulish:wght@200;300;400;500;600;700;800;900&display=swap'),
            array('id' => 'Work+Sans', 'name' => 'Work Sans', 'link' => 'Work+Sans:wght@100;200;300;400;500;600;700;800;900&display=swap'),
            array('id' => 'Roboto+Condensed', 'name' => 'Roboto Condensed', 'link' => 'Roboto+Condensed:wght@300;400;700&display=swap'),            
            array('id' => 'Barlow', 'name' => 'Barlow', 'link' => 'Barlow:wght@100;200;300;400;500;600;700;800;900&display=swap'),
            array('id' => 'Oxanium', 'name' => 'Oxanium', 'link' => 'Oxanium:wght@200;300;400;500;600;700;800&display=swap'),
            array('id' => 'Karla', 'name' => 'Karla', 'link' => 'Karla:wght@200;300;400;500;600;700;800&display=swap'),
            array('id' => 'Playfair+Display', 'name' => 'Playfair Display', 'link' => 'Playfair+Display:wght@400;500;600;700;800;900&display=swap'),
            array('id' => 'Lato', 'name' => 'Lato', 'link' => 'Lato:wght@100;300;400;700;900&display=swap'),
            array('id' => 'Raleway', 'name' => 'Raleway', 'link' => 'Raleway:wght@400;500;600;700;800&display=swap'),
            array('id' => 'Oxygen', 'name' => 'Oxygen', 'link' => 'Oxygen:wght@300;400;700&display=swap'),
            array('id' => 'Hind+Siliguri', 'name' => 'Hind Siliguri', 'link' => 'Hind+Siliguri:wght@300;400;500;600;700&display=swap'),
            array('id' => 'Nunito+Sans', 'name' => 'Nunito Sans', 'link' => 'Nunito+Sans:wght@200;300;400;600;700;800;900&display=swap'),                         
            array('id' => 'Jost', 'name' => 'Jost', 'link' => 'Jost:wght@100;200;300;400;500;600;700;800;900&display=swap'),            
            array('id' => 'Poppins', 'name' => 'Poppins', 'link' => 'Poppins:wght@100;200;300;400;500;600;700;800;900&display=swap'),
            array('id' => 'Roboto', 'name' => 'Roboto', 'link' => 'Roboto:wght@100;300;400;500;700;900&display=swap'),
            array('id' => 'Heebo', 'name' => 'Heebo', 'link' => 'Heebo:wght@100;200;300;400;500;600;700;800;900&display=swap'),
            //array('id' => 'Oswald', 'name' => 'Oswald', 'link' => 'Oswald:wght@200;300;400;500;600;700&display=swap'),
            //array('id' => 'Rajdhani', 'name' => 'Rajdhani', 'link' => 'Rajdhani:wght@300;400;500;600;700&display=swap'),
        );
        
        $fontSizeArray  =  array(
            array('id' => '13px', 'name' => '13px'),
            array('id' => '14px', 'name' => '14px'),
            array('id' => '15px', 'name' => '15px'),
            array('id' => '16px', 'name' => '16px'),
            array('id' => '17px', 'name' => '17px'),
            array('id' => '18px', 'name' => '18px'),
            array('id' => '20px', 'name' => '20px'),
            array('id' => '22px', 'name' => '22px'),
            array('id' => '24px', 'name' => '24px'),
        );
        
        if (Configuration::get('CPCONTROL_PANEL')) {   
            $this->context->smarty->assign('image_url', $this->context->link->getMediaLink(_MODULE_DIR_.'cp_themeoptions/views/img/pattern'));
            $this->context->smarty->assign('fontlist_array', $fontArray);
            $this->context->smarty->assign('fontsize_array', $fontSizeArray);

            return $this->display(__FILE__, 'controlpanel.tpl');
        }
    }

    public function postProcess()
    {
        if (Tools::isSubmit('submitThemeSettings')) {
            
            // Upload Body Background Image
            $values = array();
            $update_images_values = false;

            if (isset($_FILES['CPBOX_BGIMG']) && !empty($_FILES['CPBOX_BGIMG']['tmp_name'])) {
                if ($error = ImageManager::validateUpload($_FILES['CPBOX_BGIMG'], 4000000)) {
                    return $this->displayError($error);
                } else {
                    $file_name = $_FILES['CPBOX_BGIMG']['name'];
                    if (!move_uploaded_file($_FILES['CPBOX_BGIMG']['tmp_name'], dirname(__FILE__).DIRECTORY_SEPARATOR.'views'.DIRECTORY_SEPARATOR.'img'.DIRECTORY_SEPARATOR.$file_name)) {
                        return $this->displayError($this->trans('An error occurred while attempting to upload the file.', array(), 'Admin.Notifications.Error'));
                    } else {
                        $values['CPBOX_BGIMG'] = $file_name; 
                        $update_images_values = true;
                    }
                }
            } 

            if ($update_images_values) {
                Configuration::updateValue('CPBOX_BGIMG', $values['CPBOX_BGIMG']);
            }

            $form_values = $this->getGroupFieldsValues();
            foreach (array_keys($form_values) as $key) {
                if($key == "CPBOX_BGIMG"){
                    continue;
                }
                Configuration::updateValue($key, Tools::getValue($key));
            }

            $this->_clearCache($this->templateFile);

            return $this->displayConfirmation($this->trans('Theme design settings have been updated.', array(), 'Admin.Notifications.Success'));
        }
        
       
        if (Tools::isSubmit('deleteBoxBkgImage')) {
            $general_settings = Configuration::get('CPBOX_BGIMG');
            if ($general_settings) {
                $image_path = $this->local_path.$this->image_folder.$general_settings;

                if (file_exists($image_path)) {
                    unlink($image_path);
                }
                Configuration::updateValue('CPBOX_BGIMG', '');
                $this->_clearCache('*');
            }
            
            return $this->displayConfirmation($this->trans('Box image deleted successfully', array(), 'Admin.Notifications.Success'));
            Tools::redirectAdmin($this->currentIndex.'&configure='.$this->name.'&token='.Tools::getAdminTokenLite('AdminModules'));
        }
        return '';
    }

    public function getContent()
    {
        return $this->postProcess().$this->renderForm();
    }

    public function renderForm()
    {
        
        $boxbg_image_style = array(
            'query' => array(
                array('id' => 'repeat', 'name' => 'Repeat'),
                array('id' => 'strech', 'name' => 'Strech'),
            ),
            'id' => 'id',
            'name' => 'name',
        );

        $fontsize_options = array(
            'query' => array(
                array('id' => '13px', 'name' => '13px'),
                array('id' => '14px', 'name' => '14px'),
                array('id' => '15px', 'name' => '15px'),
                array('id' => '16px', 'name' => '16px'),
                array('id' => '17px', 'name' => '17px'),
                array('id' => '18px', 'name' => '18px'),
                array('id' => '20px', 'name' => '20px'),
                array('id' => '22px', 'name' => '22px'),
                array('id' => '24px', 'name' => '24px'),
            ),
            'id' => 'id',
            'name' => 'name',
        );

        $font_options = array(
            'query' => array(
                array('id' => 'Inter', 'name' => 'Inter'),
                array('id' => 'Roboto+Slab', 'name' => 'Roboto Slab'),
                array('id' => 'Open+Sans', 'name' => 'Open Sans'),
                array('id' => 'Poppins', 'name' => 'Poppins'),
                array('id' => 'Lato', 'name' => 'Lato'),
                array('id' => 'Raleway', 'name' => 'Raleway'),
                array('id' => 'Roboto', 'name' => 'Roboto'),
                array('id' => 'Oxygen', 'name' => 'Oxygen'),
                array('id' => 'Jost', 'name' => 'Jost'),
                array('id' => 'Lora', 'name' => 'Lora'),
                array('id' => 'Hind+Siliguri', 'name' => 'Hind Siliguri'), 
                array('id' => 'Montserrat', 'name' => 'Montserrat'),
                array('id' => 'Oswald', 'name' => 'Oswald'),
                array('id' => 'Nunito+Sans', 'name' => 'Nunito Sans'),
                array('id' => 'Roboto+Condensed', 'name' => 'Roboto Condensed'),
                array('id' => 'Heebo', 'name' => 'Heebo'),
                array('id' => 'Playfair+Display', 'name' => 'Playfair Display'),
                array('id' => 'Rajdhani', 'name' => 'Rajdhani'),
                array('id' => 'Mulish', 'name' => 'Mulish'),
                array('id' => 'Merriweather', 'name' => 'Merriweather'),
                array('id' => 'Work+Sans', 'name' => 'Work Sans'),
                array('id' => 'Oxanium', 'name' => 'Oxanium'),
                array('id' => 'Karla', 'name' => 'Karla'),
                array('id' => 'Barlow', 'name' => 'Barlow'),
            ),
            'id' => 'id',
            'name' => 'name',
        );
        
        $boxbg_image_url = false;
        $boxbg_image_size = false;
        if (Configuration::get('CPBOX_BGIMG')) {
            $boxbg_image_url = $this->_path.$this->image_folder. Configuration::get('CPBOX_BGIMG');
            $boxbg_image_size = filesize($this->local_path.$this->image_folder.Configuration::get('CPBOX_BGIMG')) / 1000;
        }

        $fields_form = array(
            'form' => array(
                'legend' => array(
                    'title' => $this->trans('Theme Design Settings', array(), 'Admin.Global'),
                    'icon' => 'icon-cogs'
                ),
                'input' => array(
                    array(
                        'type' => 'switch',
                        'label' => $this->trans('Control Panel'),
                        'name' => 'CPCONTROL_PANEL',
                        'desc' => $this->trans('Enable this option to see controll panel on frontend'),
                        'is_bool' => true,
                        'values'    => array(
                            array(
                                'id'    => 'active_on',
                                'value' => 1,
                                'label' => $this->trans('Enable')
                            ),
                            array(
                                'id'    => 'active_off',
                                'value' => 0,
                                'label' => $this->trans('Disable')
                            )
                        ),
                    ),
                    array(
                        'type' => 'color',
                        'name' => 'CPPRIMARY_COLOR',
                        'label' => $this->trans('Primary Color'),
                    ),
                    array(
                        'type' => 'color',
                        'name' => 'CPSECONDARY_COLOR',
                        'label' => $this->trans('Secondary Color'),
                    ),
                    array(
                        'type' => 'color',
                        'name' => 'CPPRICE_COLOR',
                        'label' => $this->trans('Price Color'),
                    ),
                    array(
                        'type' => 'color',
                        'name' => 'CPLINKHOVER_COLOR',
                        'label' => $this->trans('Link Hover Color'),
                    ),
                    array(
                        'type' => 'select',
                        'label' => $this->trans('Body Font'),
                        'name' => 'CPBODY_FONT',
                        'options' => $font_options,
                        'desc' => $this->trans('Select your body font.'),
                    ),
                    array(
                        'type' => 'select',
                        'label' => $this->trans('Body Font Size'),
                        'name' => 'CPBODY_FONT_SIZE',
                        'options' => $fontsize_options,
                        'desc' => $this->trans('Select your body font size.'),
                    ),
                    array(
                        'type' => 'select',
                        'label' => $this->trans('Title Font'),
                        'name' => 'CPTITLE_FONT',
                        'options' => $font_options,
                        'desc' => $this->trans('Select your title font.'),
                    ),
                    array(
                        'type' => 'select',
                        'label' => $this->trans('Title Font Size'),
                        'name' => 'CPTITLE_FONT_SIZE',
                        'options' => $fontsize_options,
                        'desc' => $this->trans('Select your title font size.'),
                        'form_group_class' => 'page-header',
                    ),
                    array(
                        'type' => 'switch',
                        'label' => $this->trans('Box Layout'),
                        'name' => 'CPBOX_LAYOUT',
                        'desc' => $this->trans('Enable this option to make your store design Box Layout'),
                        'is_bool' => true,
                        'values'    => array(
                            array(
                                'id'    => 'active_on',
                                'value' => 1,
                                'label' => $this->trans('Enable')
                            ),
                            array(
                                'id'    => 'active_off',
                                'value' => 0,
                                'label' => $this->trans('Disable')
                            )
                        ),
                    ),                    
                    array(
                        'type' => 'color',
                        'name' => 'CPBOX_BODYBKG_COLOR',
                        'label' => $this->trans('Box Layout Background Color'),
                    ),
                    array(
                        'type' => 'file',
                        'label' => $this->trans('Box Background Image'),
                        'name' => 'CPBOX_BGIMG',
                        'display_image' => true,
                        'image' => $boxbg_image_url ? '<img src="'.$boxbg_image_url.'" alt="" class="img-thumbnail" style="max-width: 100px;" />' : false,
                        'size' => $boxbg_image_size,
                        'delete_url' => $this->currentIndex.'&token='.Tools::getAdminTokenLite('AdminModules').'&deleteBoxBkgImage',
                        'desc' => $this->trans('Set background image for boxed layout.'),
                    ),
                    array(
                        'type' => 'select',
                        'label' => $this->trans('Box Background Image Style'),
                        'name' => 'CPBOX_BGIMG_STYLE',
                        'options' => $boxbg_image_style,
                        'desc' => $this->l('How a background image will be displayed.'),
                    ),
                    array(
                        'type' => 'switch',
                        'label' => $this->trans('Sticky Header'),
                        'name' => 'CPSTICKY_HEADER',
                        'desc' => $this->trans('Enable this option to make your store header sticky while page scroll down'),
                        'is_bool' => true,
                        'values'    => array(
                            array(
                                'id'    => 'active_on',
                                'value' => 1,
                                'label' => $this->trans('Enable')
                            ),
                            array(
                                'id'    => 'active_off',
                                'value' => 0,
                                'label' => $this->trans('Disable')
                            )
                        ),
                    ),
                    array(
                        'type' => 'switch',
                        'label' => $this->trans('Border Radius'),
                        'name' => 'CPBORDER_RADIUS',
                        'desc' => $this->trans('Enable this option to apply 4px border radius'),
                        'is_bool' => true,
                        'values'    => array(
                            array(
                                'id'    => 'active_on',
                                'value' => 1,
                                'label' => $this->trans('Enable')
                            ),
                            array(
                                'id'    => 'active_off',
                                'value' => 0,
                                'label' => $this->trans('Disable')
                            )
                        ),
                    ),
                    array(
                        'type' => 'switch',
                        'label' => $this->trans('Display Product Color Variant'),
                        'name' => 'CPDISPLAY_PRODUCT_VARIANTS',
                        'desc' => $this->trans('Enable this option to display product color variant on every product list page.'),
                        'is_bool' => true,
                        'values'    => array(
                            array(
                                'id'    => 'active_on',
                                'value' => 1,
                                'label' => $this->trans('Enable')
                            ),
                            array(
                                'id'    => 'active_off',
                                'value' => 0,
                                'label' => $this->trans('Disable')
                            )
                        ),
                    ),
                    array(
                        'type' => 'textarea',
                        'label' => $this->trans('Custom CSS'),
                        'name' => 'CPCUSTOM_CSS',
                        'cols' => 40,
                        'rows' => 10,
                        'desc' => $this->l('Add custom css code for your site.'),
                    ),
                ),
                'submit' => array(
                    'title' => $this->trans('Save', array(), 'Admin.Actions'),
                    'name' => 'submitThemeSettings',
                )
            ),
        );
        
        $lang = new Language((int)Configuration::get('PS_LANG_DEFAULT'));

        $helper = new HelperForm();
        $helper->show_toolbar = false;
        $helper->table = $this->table;
        $helper->default_form_language = $lang->id;
        $helper->module = $this;
        $helper->allow_employee_form_lang = Configuration::get('PS_BO_ALLOW_EMPLOYEE_FORM_LANG') ? Configuration::get('PS_BO_ALLOW_EMPLOYEE_FORM_LANG') : 0;
        $helper->identifier = $this->identifier;
        //$helper->submit_action = 'submitStoreConf';
        $helper->currentIndex = $this->context->link->getAdminLink('AdminModules', false).'&configure='.$this->name.'&tab_module='.$this->tab.'&module_name='.$this->name;
        $helper->token = Tools::getAdminTokenLite('AdminModules');
        $helper->tpl_vars = array(
            'uri' => $this->getPathUri(),
            'fields_value' => $this->getConfigFieldsValues(),
            'languages' => $this->context->controller->getLanguages(),
            'id_language' => $this->context->language->id
        );

        return $helper->generateForm(array(
            $fields_form            
        ));
    }

    public function getConfigFieldsValues()
    {
       
        return $this->getGroupFieldsValues();
    }
    
    public function renderWidget($hookName, array $params)
    {
        if (!$this->isCached($this->templateFile, $this->getCacheId('cp_themeoptions'))) {
            $this->smarty->assign($this->getWidgetVariables($hookName, $params));
        }
        return $this->fetch($this->templateFile, $this->getCacheId('cp_themeoptions'));
    }

    public function getWidgetVariables($hookName, array $params)
    {
        $fields = array();
        $fields = $this->getGroupFieldsValues();
        $fields['image_dir_url'] = $this->context->link->getMediaLink(_MODULE_DIR_) . 'cp_themeoptions/views/img/';
        $fields['body_fontfamily'] =  str_replace( '+', ' ', Configuration::get('CPBODY_FONT'));
        $fields['title_fontfamily'] =  str_replace( '+', ' ', Configuration::get('CPTITLE_FONT'));
        $this->smarty->assign($fields);
        
    }
}

